@@ -15,14 +15,12 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
 #include "php.h"
-#include "php_ini.h"
 #include "php_ctype.h"
 #include "ctype_arginfo.h"
-#include "SAPI.h"
 #include "ext/standard/info.h"
 
 #include <ctype.h>
