@@ -15,11 +15,10 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
 #include "php.h"
-#include "php_ini.h"
 #include "php_gmp.h"
 #include "php_gmp_int.h"
 #include "ext/standard/info.h"
@@ -31,6 +30,7 @@
 
 /* Needed for gmp_random() */
 #include "ext/random/php_random.h"
+#include "ext/random/php_random_csprng.h"
 
 #ifndef mpz_fits_si_p
 # define mpz_fits_si_p mpz_fits_slong_p
@@ -183,6 +183,7 @@ if (IS_GMP(zval)) {                                               \
 	gmp_create(return_value, &gmpnumber)
 
 static void gmp_strval(zval *result, mpz_t gmpnum, int base);
+static zend_result convert_zstr_to_gmp(mpz_t gmp_number, const zend_string *val, zend_long base, uint32_t arg_pos);
 static zend_result convert_to_gmp(mpz_t gmpnumber, zval *val, zend_long base, uint32_t arg_pos);
 static void gmp_cmp(zval *return_value, zval *a_arg, zval *b_arg, bool is_operator);
 
@@ -302,6 +303,10 @@ static zend_result gmp_cast_object(zend_object *readobj, zval *writeobj, int typ
 			ZVAL_DOUBLE(writeobj, mpz_get_d(gmpnum));
 		}
 		return SUCCESS;
+	case _IS_BOOL:
+		gmpnum = GET_GMP_OBJECT_FROM_OBJ(readobj)->num;
+		ZVAL_BOOL(writeobj, mpz_sgn(gmpnum) != 0);
+		return SUCCESS;
 	default:
 		return FAILURE;
 	}
@@ -475,14 +480,13 @@ static zend_result gmp_do_operation_ex(uint8_t opcode, zval *result, zval *op1,
 static zend_result gmp_do_operation(uint8_t opcode, zval *result, zval *op1, zval *op2) /* {{{ */
 {
 	zval op1_copy;
-	int retval;
 
 	if (result == op1) {
 		ZVAL_COPY_VALUE(&op1_copy, op1);
 		op1 = &op1_copy;
 	}
 
-	retval = gmp_do_operation_ex(opcode, result, op1, op2);
+	zend_result retval = gmp_do_operation_ex(opcode, result, op1, op2);
 
 	if (retval == SUCCESS && op1 == &op1_copy) {
 		zval_ptr_dtor(op1);
@@ -554,7 +558,7 @@ static int gmp_unserialize(zval *object, zend_class_entry *ce, const unsigned ch
 	zv = var_tmp_var(&unserialize_data);
 	if (!php_var_unserialize(zv, &p, max, &unserialize_data)
 		|| Z_TYPE_P(zv) != IS_STRING
-		|| convert_to_gmp(gmpnum, zv, 10, 0) == FAILURE
+		|| convert_zstr_to_gmp(gmpnum, Z_STR_P(zv), 10, 0) == FAILURE
 	) {
 		zend_throw_exception(NULL, "Could not unserialize number", 0);
 		goto exit;
@@ -647,7 +651,13 @@ static zend_result convert_zstr_to_gmp(mpz_t gmp_number, const zend_string *val,
 	const char *num_str = ZSTR_VAL(val);
 	bool skip_lead = false;
 
-	if (ZSTR_LEN(val) >= 2 && num_str[0] == '0') {
+	size_t num_len = ZSTR_LEN(val);
+	while (isspace(*num_str)) {
+		++num_str;
+		--num_len;
+	}
+
+	if (num_len >= 2 && num_str[0] == '0') {
 		if ((base == 0 || base == 16) && (num_str[1] == 'x' || num_str[1] == 'X')) {
 			base = 16;
 			skip_lead = true;
@@ -937,7 +947,7 @@ static inline void _gmp_unary_opl(INTERNAL_FUNCTION_PARAMETERS, gmp_unary_opl_t
 static bool gmp_verify_base(zend_long base, uint32_t arg_num)
 {
 	if (base && (base < 2 || base > GMP_MAX_BASE)) {
-		zend_argument_value_error(arg_num, "must be between 2 and %d", GMP_MAX_BASE);
+		zend_argument_value_error(arg_num, "must be 0 or between 2 and %d", GMP_MAX_BASE);
 		return false;
 	}
 
@@ -980,12 +990,12 @@ ZEND_FUNCTION(gmp_init)
 }
 /* }}} */
 
-int gmp_import_export_validate(zend_long size, zend_long options, int *order, int *endian)
+static bool gmp_import_export_validate(zend_long size, zend_long options, int *order, int *endian)
 {
 	if (size < 1) {
 		/* size argument is in second position */
 		zend_argument_value_error(2, "must be greater than or equal to 1");
-		return FAILURE;
+		return false;
 	}
 
 	switch (options & (GMP_LSW_FIRST | GMP_MSW_FIRST)) {
@@ -997,9 +1007,9 @@ int gmp_import_export_validate(zend_long size, zend_long options, int *order, in
 			*order = 1;
 			break;
 		default:
-			/* options argument is in second position */
+			/* options argument is in third position */
 			zend_argument_value_error(3, "cannot use multiple word order options");
-			return FAILURE;
+			return false;
 	}
 
 	switch (options & (GMP_LITTLE_ENDIAN | GMP_BIG_ENDIAN | GMP_NATIVE_ENDIAN)) {
@@ -1014,12 +1024,12 @@ int gmp_import_export_validate(zend_long size, zend_long options, int *order, in
 			*endian = 0;
 			break;
 		default:
-			/* options argument is in second position */
+			/* options argument is in third position */
 			zend_argument_value_error(3, "cannot use multiple endian options");
-			return FAILURE;
+			return false;
 	}
 
-	return SUCCESS;
+	return true;
 }
 
 /* {{{ Imports a GMP number from a binary string */
@@ -1036,7 +1046,7 @@ ZEND_FUNCTION(gmp_import)
 		RETURN_THROWS();
 	}
 
-	if (gmp_import_export_validate(size, options, &order, &endian) == FAILURE) {
+	if (!gmp_import_export_validate(size, options, &order, &endian)) {
 		RETURN_THROWS();
 	}
 
@@ -1065,7 +1075,7 @@ ZEND_FUNCTION(gmp_export)
 		RETURN_THROWS();
 	}
 
-	if (gmp_import_export_validate(size, options, &order, &endian) == FAILURE) {
+	if (!gmp_import_export_validate(size, options, &order, &endian)) {
 		RETURN_THROWS();
 	}
 
@@ -1662,11 +1672,15 @@ ZEND_FUNCTION(gmp_invert)
 		RETURN_THROWS();
 	}
 
+	if (Z_TYPE_P(b_arg) == IS_LONG && Z_LVAL_P(b_arg) == 0) {
+		zend_throw_exception_ex(zend_ce_division_by_zero_error, 0, "Division by zero");
+		RETURN_THROWS();
+	}
+
 	FETCH_GMP_ZVAL(gmpnum_a, a_arg, temp_a, 1);
 	FETCH_GMP_ZVAL_DEP(gmpnum_b, b_arg, temp_b, temp_a, 2);
 
-	// TODO Early check if b_arg IS_LONG?
-	if (0 == mpz_cmp_ui(gmpnum_b, 0)) {
+	if (!mpz_cmp_ui(gmpnum_b, 0)) {
 		zend_throw_exception_ex(zend_ce_division_by_zero_error, 0, "Division by zero");
 		FREE_GMP_TEMP(temp_a);
 		FREE_GMP_TEMP(temp_b);
@@ -1807,9 +1821,9 @@ static void gmp_init_random(void)
 		/* Initialize */
 		gmp_randinit_mt(GMPG(rand_state));
 		/* Seed */
-		zend_long seed = 0;
-		if (php_random_bytes_silent(&seed, sizeof(zend_long)) == FAILURE) {
-			seed = GENERATE_SEED();
+		unsigned long int seed = 0;
+		if (php_random_bytes_silent(&seed, sizeof(seed)) == FAILURE) {
+			seed = (unsigned long int)php_random_generate_fallback_seed();
 		}
 		gmp_randseed_ui(GMPG(rand_state), seed);
 
@@ -2178,7 +2192,7 @@ ZEND_METHOD(GMP, __unserialize)
 
 	zval *num = zend_hash_index_find(data, 0);
 	if (!num || Z_TYPE_P(num) != IS_STRING ||
-			convert_to_gmp(GET_GMP_FROM_ZVAL(ZEND_THIS), num, 16, 0) == FAILURE) {
+			convert_zstr_to_gmp(GET_GMP_FROM_ZVAL(ZEND_THIS), Z_STR_P(num), 16, /* arg_pos */ 0) == FAILURE) {
 		zend_throw_exception(NULL, "Could not unserialize number", 0);
 		RETURN_THROWS();
 	}
