@@ -14,14 +14,12 @@ ZEND_END_ARG_INFO()
 ZEND_BEGIN_ARG_WITH_TENTATIVE_RETURN_TYPE_INFO_EX(arginfo_class_IntlIterator_valid, 0, 0, _IS_BOOL, 0)
 ZEND_END_ARG_INFO()
 
-
 ZEND_METHOD(IntlIterator, current);
 ZEND_METHOD(IntlIterator, key);
 ZEND_METHOD(IntlIterator, next);
 ZEND_METHOD(IntlIterator, rewind);
 ZEND_METHOD(IntlIterator, valid);
 
-
 static const zend_function_entry class_IntlIterator_methods[] = {
 	ZEND_ME(IntlIterator, current, arginfo_class_IntlIterator_current, ZEND_ACC_PUBLIC)
 	ZEND_ME(IntlIterator, key, arginfo_class_IntlIterator_key, ZEND_ACC_PUBLIC)
@@ -181,8 +179,7 @@ static zend_class_entry *register_class_IntlIterator(zend_class_entry *class_ent
 	zend_class_entry ce, *class_entry;
 
 	INIT_CLASS_ENTRY(ce, "IntlIterator", class_IntlIterator_methods);
-	class_entry = zend_register_internal_class_ex(&ce, NULL);
-	class_entry->ce_flags |= ZEND_ACC_NOT_SERIALIZABLE;
+	class_entry = zend_register_internal_class_with_flags(&ce, NULL, ZEND_ACC_NOT_SERIALIZABLE);
 	zend_class_implements(class_entry, 1, class_entry_Iterator);
 
 	return class_entry;
