@@ -53,23 +53,21 @@ PHP_RINIT_FUNCTION(mbstring);
 PHP_RSHUTDOWN_FUNCTION(mbstring);
 PHP_MINFO_FUNCTION(mbstring);
 
-MBSTRING_API char *php_mb_safe_strrchr_ex(const char *s, unsigned int c,
-                                    size_t nbytes, const mbfl_encoding *enc);
-MBSTRING_API char *php_mb_safe_strrchr(const char *s, unsigned int c,
-                                 size_t nbytes);
+MBSTRING_API char *php_mb_safe_strrchr(const char *s, unsigned int c, size_t nbytes, const mbfl_encoding *enc);
 
-MBSTRING_API char *php_mb_convert_encoding_ex(
+MBSTRING_API zend_string* php_mb_convert_encoding_ex(
 		const char *input, size_t length,
-		const mbfl_encoding *to_encoding, const mbfl_encoding *from_encoding, size_t *output_len);
-MBSTRING_API char * php_mb_convert_encoding(
+		const mbfl_encoding *to_encoding, const mbfl_encoding *from_encoding);
+MBSTRING_API zend_string* php_mb_convert_encoding(
 		const char *input, size_t length, const mbfl_encoding *to_encoding,
-		const mbfl_encoding **from_encodings, size_t num_from_encodings, size_t *output_len);
+		const mbfl_encoding **from_encodings, size_t num_from_encodings);
 
-MBSTRING_API size_t php_mb_mbchar_bytes_ex(const char *s, const mbfl_encoding *enc);
-MBSTRING_API size_t php_mb_mbchar_bytes(const char *s);
+MBSTRING_API size_t php_mb_mbchar_bytes(const char *s, const mbfl_encoding *enc);
 
-MBSTRING_API size_t php_mb_stripos(int mode, const char *old_haystack, size_t old_haystack_len, const char *old_needle, size_t old_needle_len, zend_long offset, const mbfl_encoding *encoding);
-MBSTRING_API int php_mb_check_encoding(const char *input, size_t length, const mbfl_encoding *encoding);
+MBSTRING_API size_t php_mb_stripos(bool mode, zend_string *haystack, zend_string *needle, zend_long offset, const mbfl_encoding *enc);
+MBSTRING_API bool php_mb_check_encoding(const char *input, size_t length, const mbfl_encoding *encoding);
+
+MBSTRING_API const mbfl_encoding* mb_guess_encoding_for_strings(const unsigned char **strings, size_t *str_lengths, size_t n, const mbfl_encoding **elist, unsigned int elist_size, bool strict, bool order_significant);
 
 ZEND_BEGIN_MODULE_GLOBALS(mbstring)
 	char *internal_encoding_name;
@@ -90,15 +88,17 @@ ZEND_BEGIN_MODULE_GLOBALS(mbstring)
 	size_t current_detect_order_list_size;
 	enum mbfl_no_encoding *default_detect_order_list;
 	size_t default_detect_order_list_size;
+	HashTable *all_encodings_list;
 	int filter_illegal_mode;
-	int filter_illegal_substchar;
+	uint32_t filter_illegal_substchar;
 	int current_filter_illegal_mode;
-	int current_filter_illegal_substchar;
+	uint32_t current_filter_illegal_substchar;
 	enum mbfl_no_language language;
 	bool encoding_translation;
 	bool strict_detection;
 	size_t illegalchars;
-	mbfl_buffer_converter *outconv;
+	bool outconv_enabled;
+	unsigned int outconv_state;
     void *http_output_conv_mimetypes;
 #ifdef HAVE_MBREGEX
     struct _zend_mb_regex_globals *mb_regex_globals;
