@@ -959,7 +959,7 @@ static int phar_tar_setupmetadata(zval *zv, void *argument) /* {{{ */
 }
 /* }}} */
 
-void phar_tar_flush(phar_archive_data *phar, zend_string *user_stub, bool is_default_stub, char **error) /* {{{ */
+int phar_tar_flush(phar_archive_data *phar, zend_string *user_stub, bool is_default_stub, char **error) /* {{{ */
 {
 	static const char newstub[] = "<?php // tar-based phar archive stub file\n__HALT_COMPILER();";
 	static const char halt_stub[] = "__HALT_COMPILER();";
@@ -986,7 +986,7 @@ void phar_tar_flush(phar_archive_data *phar, zend_string *user_stub, bool is_def
 		if (error) {
 			spprintf(error, 0, "internal error: attempt to flush cached tar-based phar \"%s\"", phar->fname);
 		}
-		return;
+		return EOF;
 	}
 
 	if (phar->is_data) {
@@ -1001,7 +1001,7 @@ void phar_tar_flush(phar_archive_data *phar, zend_string *user_stub, bool is_def
 		if (entry.fp == NULL) {
 			efree(entry.filename);
 			spprintf(error, 0, "phar error: unable to create temporary file");
-			return;
+			return -1;
 		}
 		if (phar->alias_len != php_stream_write(entry.fp, phar->alias, phar->alias_len)) {
 			if (error) {
@@ -1009,7 +1009,7 @@ void phar_tar_flush(phar_archive_data *phar, zend_string *user_stub, bool is_def
 			}
 			php_stream_close(entry.fp);
 			efree(entry.filename);
-			return;
+			return EOF;
 		}
 
 		entry.uncompressed_filesize = phar->alias_len;
@@ -1029,7 +1029,7 @@ void phar_tar_flush(phar_archive_data *phar, zend_string *user_stub, bool is_def
 			if (error) {
 				spprintf(error, 0, "illegal stub for tar-based phar \"%s\"", phar->fname);
 			}
-			return;
+			return EOF;
 		}
 
 		size_t len = pos - ZSTR_VAL(user_stub) + strlen(halt_stub);
@@ -1039,7 +1039,7 @@ void phar_tar_flush(phar_archive_data *phar, zend_string *user_stub, bool is_def
 		entry.fp = php_stream_fopen_tmpfile();
 		if (entry.fp == NULL) {
 			spprintf(error, 0, "phar error: unable to create temporary file");
-			return;
+			return EOF;
 		}
 		entry.uncompressed_filesize = len + end_sequence_len;
 
@@ -1051,7 +1051,7 @@ void phar_tar_flush(phar_archive_data *phar, zend_string *user_stub, bool is_def
 				spprintf(error, 0, "unable to create stub from string in new tar-based phar \"%s\"", phar->fname);
 			}
 			php_stream_close(entry.fp);
-			return;
+			return EOF;
 		}
 
 		entry.filename = estrndup(".phar/stub.php", sizeof(".phar/stub.php")-1);
@@ -1062,14 +1062,14 @@ void phar_tar_flush(phar_archive_data *phar, zend_string *user_stub, bool is_def
 		entry.fp = php_stream_fopen_tmpfile();
 		if (entry.fp == NULL) {
 			spprintf(error, 0, "phar error: unable to create temporary file");
-			return;
+			return EOF;
 		}
 		if (sizeof(newstub)-1 != php_stream_write(entry.fp, newstub, sizeof(newstub)-1)) {
 			php_stream_close(entry.fp);
 			if (error) {
 				spprintf(error, 0, "unable to %s stub in%star-based phar \"%s\", failed", user_stub ? "overwrite" : "create", user_stub ? " " : " new ", phar->fname);
 			}
-			return;
+			return EOF;
 		}
 
 		entry.uncompressed_filesize = entry.compressed_filesize = sizeof(newstub) - 1;
@@ -1084,7 +1084,7 @@ void phar_tar_flush(phar_archive_data *phar, zend_string *user_stub, bool is_def
 					if (error) {
 						spprintf(error, 0, "unable to create stub in tar-based phar \"%s\"", phar->fname);
 					}
-					return;
+					return EOF;
 				}
 			} else {
 				php_stream_close(entry.fp);
@@ -1112,7 +1112,7 @@ nostub:
 		if (must_close_old_file) {
 			php_stream_close(oldfile);
 		}
-		return;
+		return EOF;
 	}
 
 	pass.old = oldfile;
@@ -1128,7 +1128,7 @@ nostub:
 				if (must_close_old_file) {
 					php_stream_close(oldfile);
 				}
-				return;
+				return EOF;
 			}
 		} else {
 			phar_entry_info newentry = {0};
@@ -1144,7 +1144,7 @@ nostub:
 				if (must_close_old_file) {
 					php_stream_close(oldfile);
 				}
-				return;
+				return EOF;
 			}
 
 			if (ZEND_HASH_APPLY_KEEP != phar_tar_setmetadata(&phar->metadata_tracker, mentry, error)) {
@@ -1152,7 +1152,7 @@ nostub:
 				if (must_close_old_file) {
 					php_stream_close(oldfile);
 				}
-				return;
+				return EOF;
 			}
 		}
 	}
@@ -1166,11 +1166,21 @@ nostub:
 
 		/* on error in the hash iterator above, error is set */
 		php_stream_close(newfile);
-		return;
+		return EOF;
 	}
 
 	zend_hash_apply_with_argument(&phar->manifest, phar_tar_writeheaders, (void *) &pass);
 
+	if (error && *error) {
+		if (must_close_old_file) {
+			php_stream_close(oldfile);
+		}
+
+		/* on error in the hash iterator above, error is set */
+		php_stream_close(newfile);
+		return EOF;
+	}
+
 	/* add signature for executable tars or tars explicitly set with setSignatureAlgorithm */
 	if (!phar->is_data || phar->sig_flags) {
 		if (FAILURE == phar_create_signature(phar, newfile, &signature, &signature_length, error)) {
@@ -1185,7 +1195,7 @@ nostub:
 			}
 
 			php_stream_close(newfile);
-			return;
+			return EOF;
 		}
 
 		entry.filename = ".phar/signature.bin";
@@ -1193,7 +1203,13 @@ nostub:
 		entry.fp = php_stream_fopen_tmpfile();
 		if (entry.fp == NULL) {
 			spprintf(error, 0, "phar error: unable to create temporary file");
-			return;
+
+			efree(signature);
+			if (must_close_old_file) {
+				php_stream_close(oldfile);
+			}
+			php_stream_close(newfile);
+			return EOF;
 		}
 #ifdef WORDS_BIGENDIAN
 # define PHAR_SET_32(destination, source) do { \
@@ -1219,7 +1235,7 @@ nostub:
 				php_stream_close(oldfile);
 			}
 			php_stream_close(newfile);
-			return;
+			return EOF;
 		}
 
 		efree(signature);
@@ -1233,7 +1249,7 @@ nostub:
 			}
 			/* error is set by writeheaders */
 			php_stream_close(newfile);
-			return;
+			return EOF;
 		}
 	} /* signature */
 
@@ -1249,7 +1265,7 @@ nostub:
 	/* on error in the hash iterator above, error is set */
 	if (error && *error) {
 		php_stream_close(newfile);
-		return;
+		return EOF;
 	}
 
 	if (phar->fp && pass.free_fp) {
@@ -1276,7 +1292,7 @@ nostub:
 			if (error) {
 				spprintf(error, 0, "unable to open new phar \"%s\" for writing", phar->fname);
 			}
-			return;
+			return EOF;
 		}
 
 		if (phar->flags & PHAR_FILE_COMPRESSED_GZ) {
@@ -1300,7 +1316,7 @@ nostub:
 				if (error) {
 					spprintf(error, 4096, "unable to compress all contents of phar \"%s\" using zlib, PHP versions older than 5.2.6 have a buggy zlib", phar->fname);
 				}
-				return;
+				return EOF;
 			}
 
 			php_stream_filter_append(&phar->fp->writefilters, filter);
@@ -1327,5 +1343,6 @@ nostub:
 			php_stream_close(newfile);
 		}
 	}
+	return 0;
 }
 /* }}} */
