@@ -24,7 +24,7 @@
 #endif
 #include <stddef.h>
 
-#if HAVE_UTIME
+#ifdef HAVE_UTIME
 # ifdef PHP_WIN32
 #  include <sys/utime.h>
 # else
@@ -254,6 +254,7 @@ typedef struct _php_userstream_data php_userstream_data_t;
 static zend_result call_method_if_exists(
 		zval *object, zval *method_name, zval *retval, uint32_t param_count, zval *params)
 {
+	ZEND_ASSERT(EG(active));
 	return zend_call_method_if_exists(
 		Z_OBJ_P(object), Z_STR_P(method_name), retval, param_count, params);
 }
@@ -278,6 +279,12 @@ static void user_stream_create_object(struct php_user_stream_wrapper *uwrap, php
 		add_property_null(object, "context");
 	}
 
+	if (EG(exception) != NULL) {
+		zval_ptr_dtor(object);
+		ZVAL_UNDEF(object);
+		return;
+	}
+
 	if (uwrap->ce->constructor) {
 		zend_call_known_instance_method_with_0_params(
 			uwrap->ce->constructor, Z_OBJ_P(object), NULL);
@@ -792,7 +799,7 @@ static int php_userstreamop_seek(php_stream *stream, zend_off_t offset, int when
 
 /* parse the return value from one of the stat functions and store the
  * relevant fields into the statbuf provided */
-static int statbuf_from_array(zval *array, php_stream_statbuf *ssb)
+static void statbuf_from_array(zval *array, php_stream_statbuf *ssb)
 {
 	zval *elem;
 
@@ -810,7 +817,7 @@ static int statbuf_from_array(zval *array, php_stream_statbuf *ssb)
 	STAT_PROP_ENTRY(nlink);
 	STAT_PROP_ENTRY(uid);
 	STAT_PROP_ENTRY(gid);
-#if HAVE_STRUCT_STAT_ST_RDEV
+#ifdef HAVE_STRUCT_STAT_ST_RDEV
 	STAT_PROP_ENTRY(rdev);
 #endif
 	STAT_PROP_ENTRY(size);
@@ -826,7 +833,6 @@ static int statbuf_from_array(zval *array, php_stream_statbuf *ssb)
 
 #undef STAT_PROP_ENTRY
 #undef STAT_PROP_ENTRY_EX
-	return SUCCESS;
 }
 
 static int php_userstreamop_stat(php_stream *stream, php_stream_statbuf *ssb)
@@ -842,8 +848,8 @@ static int php_userstreamop_stat(php_stream *stream, php_stream_statbuf *ssb)
 	call_result = call_method_if_exists(&us->object, &func_name, &retval, 0, NULL);
 
 	if (call_result == SUCCESS && Z_TYPE(retval) == IS_ARRAY) {
-		if (SUCCESS == statbuf_from_array(&retval, ssb))
-			ret = 0;
+		statbuf_from_array(&retval, ssb);
+		ret = 0;
 	} else {
 		if (call_result == FAILURE) {
 			php_error_docref(NULL, E_WARNING, "%s::" USERSTREAM_STAT " is not implemented!",
@@ -1217,7 +1223,6 @@ static int user_wrapper_metadata(php_stream_wrapper *wrapper, const char *url, i
 			break;
 		default:
 			php_error_docref(NULL, E_WARNING, "Unknown option %d for " USERSTREAM_METADATA, option);
-			zval_ptr_dtor(&args[2]);
 			return ret;
 	}
 
@@ -1281,8 +1286,8 @@ static int user_wrapper_stat_url(php_stream_wrapper *wrapper, const char *url, i
 
 	if (call_result == SUCCESS && Z_TYPE(zretval) == IS_ARRAY) {
 		/* We got the info we needed */
-		if (SUCCESS == statbuf_from_array(&zretval, ssb))
-			ret = 0;
+		statbuf_from_array(&zretval, ssb);
+		ret = 0;
 	} else {
 		if (call_result == FAILURE) {
 			php_error_docref(NULL, E_WARNING, "%s::" USERSTREAM_STATURL " is not implemented!",
